ForkGraph

Trait ForkGraph 

pub trait ForkGraph {
    // Required method
    fn relationship(&self, a: Slot, b: Slot) -> BlockRelation;
}
👎Deprecated since 3.1.0:

This crate has been marked for formal inclusion in the Atlas Unstable API. From v4.0.0 onward, the atlas-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.

Maps relationship between two slots.

Required Methods

fn relationship(&self, a: Slot, b: Slot) -> BlockRelation

👎Deprecated since 3.1.0:

This crate has been marked for formal inclusion in the Atlas Unstable API. From v4.0.0 onward, the atlas-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.

Returns the BlockRelation of A to B

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors