pub type ProgramRuntimeEnvironment = Arc<BuiltinProgram<InvokeContext<'static>>>;๐Deprecated since 3.1.0:
This crate has been marked for formal inclusion in the Atlas Unstable API. From v4.0.0 onward, the atlas-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
Aliased Type
pub struct ProgramRuntimeEnvironment { /* private fields */ }